@@ -12,9 +12,17 @@ class CreatePayoutAccount:
     def Process(self, request):
         # Create request
         json_data = json.dumps(request)
-        conn = http.client.HTTPSConnection(self.endpoint)
         headers = {"Content-type": "application/json",
                    "Accept": "application/json"}
+
+        url_info = urlparse.urlparse(self.endpoint)
+        if url_info.scheme == "https":
+            conn = httplib.HTTPSConnection(
+                url_info.hostname, url_info.port or 443)
+        else:
+            conn = httplib.HTTPConnection(
+                url_info.hostname, url_info.port or 80)
+
         try:
             # Send the request
             conn.request('POST', self.route, json_data, headers)
